/****************************************************************************
** Meta object code from reading C++ file 'qinappproductqmltype_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kde-qtpurchasing/src/imports/purchasing/qinappproductqmltype_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qinappproductqmltype_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QInAppProductQmlType_t {
    QByteArrayData data[38];
    char stringdata0[506];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QInAppProductQmlType_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QInAppProductQmlType_t qt_meta_stringdata_QInAppProductQmlType = {
    {
QT_MOC_LITERAL(0, 0, 20), // "QInAppProductQmlType"
QT_MOC_LITERAL(1, 21, 17), // "purchaseSucceeded"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 18), // "QInAppTransaction*"
QT_MOC_LITERAL(4, 59, 11), // "transaction"
QT_MOC_LITERAL(5, 71, 14), // "purchaseFailed"
QT_MOC_LITERAL(6, 86, 16), // "purchaseRestored"
QT_MOC_LITERAL(7, 103, 17), // "identifierChanged"
QT_MOC_LITERAL(8, 121, 13), // "statusChanged"
QT_MOC_LITERAL(9, 135, 12), // "priceChanged"
QT_MOC_LITERAL(10, 148, 12), // "titleChanged"
QT_MOC_LITERAL(11, 161, 18), // "descriptionChanged"
QT_MOC_LITERAL(12, 180, 12), // "storeChanged"
QT_MOC_LITERAL(13, 193, 11), // "typeChanged"
QT_MOC_LITERAL(14, 205, 17), // "handleTransaction"
QT_MOC_LITERAL(15, 223, 23), // "handleProductRegistered"
QT_MOC_LITERAL(16, 247, 14), // "QInAppProduct*"
QT_MOC_LITERAL(17, 262, 7), // "product"
QT_MOC_LITERAL(18, 270, 20), // "handleProductUnknown"
QT_MOC_LITERAL(19, 291, 26), // "QInAppProduct::ProductType"
QT_MOC_LITERAL(20, 318, 10), // "identifier"
QT_MOC_LITERAL(21, 329, 8), // "purchase"
QT_MOC_LITERAL(22, 338, 11), // "resetStatus"
QT_MOC_LITERAL(23, 350, 4), // "type"
QT_MOC_LITERAL(24, 355, 11), // "ProductType"
QT_MOC_LITERAL(25, 367, 5), // "price"
QT_MOC_LITERAL(26, 373, 5), // "title"
QT_MOC_LITERAL(27, 379, 11), // "description"
QT_MOC_LITERAL(28, 391, 6), // "status"
QT_MOC_LITERAL(29, 398, 6), // "Status"
QT_MOC_LITERAL(30, 405, 5), // "store"
QT_MOC_LITERAL(31, 411, 19), // "QInAppStoreQmlType*"
QT_MOC_LITERAL(32, 431, 13), // "Uninitialized"
QT_MOC_LITERAL(33, 445, 19), // "PendingRegistration"
QT_MOC_LITERAL(34, 465, 10), // "Registered"
QT_MOC_LITERAL(35, 476, 7), // "Unknown"
QT_MOC_LITERAL(36, 484, 10), // "Consumable"
QT_MOC_LITERAL(37, 495, 10) // "Unlockable"

    },
    "QInAppProductQmlType\0purchaseSucceeded\0"
    "\0QInAppTransaction*\0transaction\0"
    "purchaseFailed\0purchaseRestored\0"
    "identifierChanged\0statusChanged\0"
    "priceChanged\0titleChanged\0descriptionChanged\0"
    "storeChanged\0typeChanged\0handleTransaction\0"
    "handleProductRegistered\0QInAppProduct*\0"
    "product\0handleProductUnknown\0"
    "QInAppProduct::ProductType\0identifier\0"
    "purchase\0resetStatus\0type\0ProductType\0"
    "price\0title\0description\0status\0Status\0"
    "store\0QInAppStoreQmlType*\0Uninitialized\0"
    "PendingRegistration\0Registered\0Unknown\0"
    "Consumable\0Unlockable"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QInAppProductQmlType[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       7,  118, // properties
       2,  146, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   89,    2, 0x06 /* Public */,
       5,    1,   92,    2, 0x06 /* Public */,
       6,    1,   95,    2, 0x06 /* Public */,
       7,    0,   98,    2, 0x06 /* Public */,
       8,    0,   99,    2, 0x06 /* Public */,
       9,    0,  100,    2, 0x06 /* Public */,
      10,    0,  101,    2, 0x06 /* Public */,
      11,    0,  102,    2, 0x06 /* Public */,
      12,    0,  103,    2, 0x06 /* Public */,
      13,    0,  104,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    1,  105,    2, 0x08 /* Private */,
      15,    1,  108,    2, 0x08 /* Private */,
      18,    2,  111,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      21,    0,  116,    2, 0x02 /* Public */,
      22,    0,  117,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void, 0x80000000 | 19, QMetaType::QString,    2,   20,

 // methods: parameters
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      20, QMetaType::QString, 0x00495103,
      23, 0x80000000 | 24, 0x0049510b,
      25, QMetaType::QString, 0x00495001,
      26, QMetaType::QString, 0x00495001,
      27, QMetaType::QString, 0x00495001,
      28, 0x80000000 | 29, 0x00495009,
      30, 0x80000000 | 31, 0x0049510b,

 // properties: notify_signal_id
       3,
       9,
       5,
       6,
       7,
       4,
       8,

 // enums: name, alias, flags, count, data
      29,   29, 0x0,    4,  156,
      24,   24, 0x0,    2,  164,

 // enum data: key, value
      32, uint(QInAppProductQmlType::Uninitialized),
      33, uint(QInAppProductQmlType::PendingRegistration),
      34, uint(QInAppProductQmlType::Registered),
      35, uint(QInAppProductQmlType::Unknown),
      36, uint(QInAppProductQmlType::Consumable),
      37, uint(QInAppProductQmlType::Unlockable),

       0        // eod
};

void QInAppProductQmlType::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QInAppProductQmlType *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->purchaseSucceeded((*reinterpret_cast< QInAppTransaction*(*)>(_a[1]))); break;
        case 1: _t->purchaseFailed((*reinterpret_cast< QInAppTransaction*(*)>(_a[1]))); break;
        case 2: _t->purchaseRestored((*reinterpret_cast< QInAppTransaction*(*)>(_a[1]))); break;
        case 3: _t->identifierChanged(); break;
        case 4: _t->statusChanged(); break;
        case 5: _t->priceChanged(); break;
        case 6: _t->titleChanged(); break;
        case 7: _t->descriptionChanged(); break;
        case 8: _t->storeChanged(); break;
        case 9: _t->typeChanged(); break;
        case 10: _t->handleTransaction((*reinterpret_cast< QInAppTransaction*(*)>(_a[1]))); break;
        case 11: _t->handleProductRegistered((*reinterpret_cast< QInAppProduct*(*)>(_a[1]))); break;
        case 12: _t->handleProductUnknown((*reinterpret_cast< QInAppProduct::ProductType(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 13: _t->purchase(); break;
        case 14: _t->resetStatus(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QInAppProduct* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QInAppProductQmlType::*)(QInAppTransaction * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QInAppProductQmlType::purchaseSucceeded)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QInAppProductQmlType::*)(QInAppTransaction * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QInAppProductQmlType::purchaseFailed)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QInAppProductQmlType::*)(QInAppTransaction * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QInAppProductQmlType::purchaseRestored)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QInAppProductQmlType::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QInAppProductQmlType::identifierChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QInAppProductQmlType::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QInAppProductQmlType::statusChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QInAppProductQmlType::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QInAppProductQmlType::priceChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QInAppProductQmlType::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QInAppProductQmlType::titleChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QInAppProductQmlType::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QInAppProductQmlType::descriptionChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QInAppProductQmlType::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QInAppProductQmlType::storeChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (QInAppProductQmlType::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QInAppProductQmlType::typeChanged)) {
                *result = 9;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QInAppProductQmlType *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->identifier(); break;
        case 1: *reinterpret_cast< ProductType*>(_v) = _t->type(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->price(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->title(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->description(); break;
        case 5: *reinterpret_cast< Status*>(_v) = _t->status(); break;
        case 6: *reinterpret_cast< QInAppStoreQmlType**>(_v) = _t->store(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QInAppProductQmlType *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIdentifier(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setType(*reinterpret_cast< ProductType*>(_v)); break;
        case 6: _t->setStore(*reinterpret_cast< QInAppStoreQmlType**>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QInAppProductQmlType::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QInAppProductQmlType.data,
    qt_meta_data_QInAppProductQmlType,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QInAppProductQmlType::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QInAppProductQmlType::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QInAppProductQmlType.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int QInAppProductQmlType::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 7;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QInAppProductQmlType::purchaseSucceeded(QInAppTransaction * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QInAppProductQmlType::purchaseFailed(QInAppTransaction * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QInAppProductQmlType::purchaseRestored(QInAppTransaction * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QInAppProductQmlType::identifierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QInAppProductQmlType::statusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QInAppProductQmlType::priceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QInAppProductQmlType::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QInAppProductQmlType::descriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QInAppProductQmlType::storeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QInAppProductQmlType::typeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
